
from quartic_sdk.core.entities import *
import quartic_sdk.utilities.constants as Constants

ENTITY_DICTIONARY = {
    Constants.ASSET_ENTITY: Asset,
    Constants.TAG_ENTITY: Tag,
    Constants.CONTEXT_FRAME_ENTITY: ContextFrame,
    Constants.CONTEXT_FRAME_OCCURRENCE_ENTITY: ContextFrameOccurrence,
    Constants.BATCH_ENTITY: Batch,
    Constants.MODEL_ENTITY: Model,
    Constants.EDGE_CONNECTOR_ENTITY: EdgeConnector
}
